@@ -17,17 +17,17 @@ use Feature::Compat::Try;
 use Future::AsyncAwait;
 use Object::Pad 0.821;
 
-class Sys::Async::Virt::Callback v0.2.3;
+class Sys::Async::Virt::Callback v0.2.4;
 
 
 use Carp qw(croak);
 use Future::Queue;
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v11.10.1;
+use Protocol::Sys::Virt::Remote::XDR v11.10.3;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
-field $_id              :reader :param;
+field $_rpc_id          :reader :param;
 field $_client          :reader :param;
 field $_deregister_call :param;
 field $_queue;
@@ -63,7 +63,7 @@ method cleanup() {
     $_client->_deregister_callback(
         $_cancelled,
         $_deregister_call,
-        $_id );
+        $_rpc_id );
 
     return;
 }
@@ -94,7 +94,7 @@ Sys::Async::Virt::Callback - Client side proxy to remote LibVirt event source
 
 =head1 VERSION
 
-v0.2.3
+v0.2.4
 
 =head1 SYNOPSIS
 
@@ -161,7 +161,7 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
 =head1 LICENSE AND COPYRIGHT
 
 
-  Copyright (C) 2024-2025 Erik Huelsmann
+  Copyright (C) 2024-2026 Erik Huelsmann
 
 All rights reserved. This program is free software;
 you can redistribute it and/or modify it under the same terms as Perl itself.
