@@ -16,7 +16,7 @@ use experimental 'signatures';
 use Future::AsyncAwait;
 use Object::Pad ':experimental(inherit_field)';
 
-class Sys::Async::Virt::Connection v0.2.3;
+class Sys::Async::Virt::Connection v0.2.4;
 
 field $_in  :inheritable = undef;
 field $_out :inheritable = undef;
@@ -32,7 +32,9 @@ use Log::Any qw($log);
 
 method _finalize_io() {
     $_eof = 1;
-    $_write_f->cancel;
+    $_write_f->fail( 'closed' ) unless $_write_f->is_ready;
+    $_read_f->fail( 'closed' )  unless $_read_f->is_ready;
+    $_read_f  = Future->fail( 'closed' );
     $_write_f = Future->fail( 'closed' );
 }
 
@@ -64,7 +66,7 @@ method is_write_eof() {
 
 async method read($type, $len) {
     die $log->fatal( "Unsupported transfer type $type" ) unless $type eq 'data';
-    return undef if $_eof;
+    return (undef, 1) if $_eof;
 
     $log->trace( "Starting read of length $len" );
     $_read_f = $_read_f->then(sub { Future::IO->read_exactly( $_in, $len ) });
@@ -73,7 +75,7 @@ async method read($type, $len) {
     $log->trace( "Finished read of length $len" );
     $_eof = not defined $data;
 
-    return $data;
+    return ($data, 0);
 }
 
 method _write_chunk($data) {
@@ -116,7 +118,7 @@ Sys::Async::Virt::Connection - Connection to LibVirt server (abstract
 
 =head1 VERSION
 
-v0.2.3
+v0.2.4
 
 =head1 SYNOPSIS
 
@@ -173,7 +175,7 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
 =head1 LICENSE AND COPYRIGHT
 
 
-  Copyright (C) 2024-2025 Erik Huelsmann
+  Copyright (C) 2024-2026 Erik Huelsmann
 
 All rights reserved. This program is free software;
 you can redistribute it and/or modify it under the same terms as Perl itself.
