@@ -16,30 +16,37 @@ use experimental 'signatures';
 use Future::AsyncAwait;
 use Object::Pad;
 
-class Sys::Async::Virt::NwFilterBinding v0.2.3;
+class Sys::Async::Virt::NwFilterBinding v0.2.4;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v11.10.1;
+use Protocol::Sys::Virt::Remote::XDR v11.10.3;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 
 
-field $_id :param :reader;
+field $_rpc_id :param :reader;
 field $_client :param :reader;
 
+method name() {
+    return $_rpc_id->{name};
+}
+
+method port() {
+    return $_client->_network_port_instance( $_rpc_id->{portdev} );
+}
 
 method delete() {
     return $_client->_call(
         $remote->PROC_NWFILTER_BINDING_DELETE,
-        { nwfilter => $_id }, empty => 1 );
+        { nwfilter => $_rpc_id }, empty => 1 );
 }
 
 async method get_xml_desc($flags = 0) {
     return await $_client->_call(
         $remote->PROC_NWFILTER_BINDING_GET_XML_DESC,
-        { nwfilter => $_id, flags => $flags // 0 }, unwrap => 'xml' );
+        { nwfilter => $_rpc_id, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
 
@@ -54,7 +61,7 @@ Sys::Async::Virt::NwFilterBinding - Client side proxy to remote LibVirt network
 
 =head1 VERSION
 
-v0.2.3
+v0.2.4
 
 =head1 SYNOPSIS
 
@@ -68,6 +75,18 @@ v0.2.3
 
 =head1 METHODS
 
+=head2 name
+
+  $name = $binding->name;
+
+Returns the name of the filter binding.
+
+=head2 port
+
+  $port = $binding->port;
+
+Returns the L<Sys::Async::Virt::NetworkPort> instance this binding associates with.
+
 =head2 delete
 
   await $binding->delete;
@@ -90,6 +109,10 @@ See documentation of L<virNWFilterBindingGetXMLDesc|https://libvirt.org/html/lib
 
 =head1 CONSTANTS
 
+
+
+
+
 =over 8
 
 
@@ -103,7 +126,7 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
 =head1 LICENSE AND COPYRIGHT
 
 
-  Copyright (C) 2024-2025 Erik Huelsmann
+  Copyright (C) 2024-2026 Erik Huelsmann
 
 All rights reserved. This program is free software;
 you can redistribute it and/or modify it under the same terms as Perl itself.
