@@ -16,12 +16,12 @@ use experimental 'signatures';
 use Future::AsyncAwait;
 use Object::Pad;
 
-class Sys::Async::Virt::Secret v0.2.3;
+class Sys::Async::Virt::Secret v0.2.4;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v11.10.1;
+use Protocol::Sys::Virt::Remote::XDR v11.10.3;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -30,32 +30,47 @@ use constant {
 };
 
 
-field $_id :param :reader;
+field $_rpc_id :param :reader;
 field $_client :param :reader;
 
+method uuid() {
+    return $_rpc_id->{uuid};
+}
+
+method uuid_string() {
+    return join( '-', unpack('H8H4H4H4H12', $_rpc_id->{uuid}) );
+}
+
+method usage_type() {
+    return $_rpc_id->{usageType};
+}
+
+method usage_id() {
+    return $_rpc_id->{usageID};
+}
 
 async method get_value($flags = 0) {
     return await $_client->_call(
         $remote->PROC_SECRET_GET_VALUE,
-        { secret => $_id, flags => $flags // 0 }, unwrap => 'value' );
+        { secret => $_rpc_id, flags => $flags // 0 }, unwrap => 'value' );
 }
 
 async method get_xml_desc($flags = 0) {
     return await $_client->_call(
         $remote->PROC_SECRET_GET_XML_DESC,
-        { secret => $_id, flags => $flags // 0 }, unwrap => 'xml' );
+        { secret => $_rpc_id, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
 method set_value($value, $flags = 0) {
     return $_client->_call(
         $remote->PROC_SECRET_SET_VALUE,
-        { secret => $_id, value => $value, flags => $flags // 0 }, empty => 1 );
+        { secret => $_rpc_id, value => $value, flags => $flags // 0 }, empty => 1 );
 }
 
 method undefine() {
     return $_client->_call(
         $remote->PROC_SECRET_UNDEFINE,
-        { secret => $_id }, empty => 1 );
+        { secret => $_rpc_id }, empty => 1 );
 }
 
 
@@ -71,7 +86,7 @@ Sys::Async::Virt::Secret - Client side proxy to remote LibVirt secret
 
 =head1 VERSION
 
-v0.2.3
+v0.2.4
 
 =head1 SYNOPSIS
 
@@ -85,6 +100,30 @@ v0.2.3
 
 =head1 METHODS
 
+=head2 uuid
+
+  $uuid = $secret->uuid;
+
+Returns a 16-byte string containing the (binary) UUID.
+
+=head2 uuid_string
+
+  $str = $secret->uuid_string;
+
+Returns the string representation of the UUID (C<xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx>).
+
+=head2 usage_type
+
+  my $usage_type = $secret->usage_type;
+
+Returns the usage type of the secret.
+
+=head2 usage_id
+
+  my $usage_id = $secret->usage_id;
+
+Returns the identifier of he object with which the secret is to be used.
+
 =head2 get_value
 
   $value = await $secret->get_value( $flags = 0 );
@@ -122,6 +161,15 @@ See documentation of L<virSecretUndefine|https://libvirt.org/html/libvirt-libvir
 
 =head1 CONSTANTS
 
+
+   my $value = Sys::Async::Virt::Secret->EVENT_DEFINED;
+
+   # - or -
+
+   my $value = $secret->EVENT_DEFINED;
+
+
+
 =over 8
 
 =item EVENT_DEFINED
@@ -137,7 +185,7 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
 =head1 LICENSE AND COPYRIGHT
 
 
-  Copyright (C) 2024-2025 Erik Huelsmann
+  Copyright (C) 2024-2026 Erik Huelsmann
 
 All rights reserved. This program is free software;
 you can redistribute it and/or modify it under the same terms as Perl itself.
